Index: libmpc/branches/r2d/libmpcpsy/ans.c
===================================================================
--- libmpc/branches/r2d/libmpcpsy/ans.c	(revision 194)
+++ libmpc/branches/r2d/libmpcpsy/ans.c	(revision 195)
@@ -62,5 +62,5 @@
 
 // calculates optimal reflection coefficients and time response of a prediction filter in LPC analysis
-static __inline void
+static mpc_inline void
 durbin_akf_to_kh1( float*        k,     // out: reflection coefficients
                    float*        h,     // out: time response
@@ -70,5 +70,5 @@
 }
 
-static __inline void
+static mpc_inline void
 durbin_akf_to_kh2( float*        k,     // out: reflection coefficients
                    float*        h,     // out: time response
@@ -83,5 +83,5 @@
 }
 
-static __inline void
+static mpc_inline void
 durbin_akf_to_kh3( float*        k,     // out: reflection coefficients
                    float*        h,     // out: time response
@@ -104,5 +104,5 @@
 
 
-static __inline void
+static mpc_inline void
 durbin_akf_to_kh ( float*        k,     // out: reflection coefficients
                    float*        h,     // out: time response
Index: libmpc/branches/r2d/libmpcpsy/cvd.c
===================================================================
--- libmpc/branches/r2d/libmpcpsy/cvd.c	(revision 194)
+++ libmpc/branches/r2d/libmpcpsy/cvd.c	(revision 195)
@@ -222,5 +222,5 @@
 #else
 
-static __inline float   /* This is a rough estimation with an accuracy of |x|<0.0037 */
+static mpc_inline float   /* This is a rough estimation with an accuracy of |x|<0.0037 */
 logfast ( float x )
 {
Index: libmpc/branches/r2d/libmpcpsy/fft4g.c
===================================================================
--- libmpc/branches/r2d/libmpcpsy/fft4g.c	(revision 194)
+++ libmpc/branches/r2d/libmpcpsy/fft4g.c	(revision 195)
@@ -26,10 +26,10 @@
 static          void  makewt       ( const int nw, int* ip, float* w );
 static          void  makect       ( const int nc, int* ip, float* c );
-static __inline void  bitrv2       ( const int n, int* ip, float* a );                   //
-static __inline void  cftfsub      ( const int n, float* a, float* w );                  //
-static __inline void  rftfsub      ( const int n, float* a, int nc, float* c );          //
-static __inline void  cft1st       ( const int n, float* a, float* w );                  //
-static __inline void  cftmdl_i386  ( const int n, const int l, float* a, float* w );     // 5648
-// static __inline void  cftmdl_3DNow ( const int n, const int l, float* a, float* w );     // 4954
+static mpc_inline void  bitrv2       ( const int n, int* ip, float* a );                   //
+static mpc_inline void  cftfsub      ( const int n, float* a, float* w );                  //
+static mpc_inline void  rftfsub      ( const int n, float* a, int nc, float* c );          //
+static mpc_inline void  cft1st       ( const int n, float* a, float* w );                  //
+static mpc_inline void  cftmdl_i386  ( const int n, const int l, float* a, float* w );     // 5648
+// static mpc_inline void  cftmdl_3DNow ( const int n, const int l, float* a, float* w );     // 4954
 
 #if 0
@@ -396,6 +396,6 @@
 }
 
-// extern void Cdecl cftmdl_3DNow_1 ( const int n, const int l, float* a, float* w );
-// extern void Cdecl cftmdl_3DNow_2 ( const int n, const int l, float* a, float* w );
+// extern void mpc_cdecl cftmdl_3DNow_1 ( const int n, const int l, float* a, float* w );
+// extern void mpc_cdecl cftmdl_3DNow_2 ( const int n, const int l, float* a, float* w );
 
 
